<<<<<<< HEAD Standard error estimation based on influence function expansion for DR method. — StdErrorEstimationDR • stratifiedSSLStandard error estimation based on influence function expansion for DR method. — StdErrorEstimationDR • stratifiedSSL

Standard error estimation based on influence function expansion for DR method.

<<<<<<< HEAD
StdErrorEstimationDR(X_labeled, X_unlabeled, y, beta_dr, resid, proj_dr)
=======

Usage

StdErrorEstimationDR(X_labeled, X_unlabeled, y, beta_dr, resid, proj_dr)
>>>>>>> e32a060aec520f495c0371cd7ee97e715754fa71

Arguments

X_labeled

Covariate matrix for labeled data set.

X_unlabeled

Covariate matrix for unlabeled data set.

y

Numeric outcome vector.

beta_dr

DR regression parameter estimate to compute the score function.

resid

Estimated residual.

proj_dr

DR projection.

<<<<<<< HEAD

Value

Standard error estimate for DR method.

=======

Value

Standard error estimate for DR method.

>>>>>>> e32a060aec520f495c0371cd7ee97e715754fa71