HEAD
StdErrorEstimationDR.RdStandard error estimation based on influence function expansion for DR method.
StdErrorEstimationDR(X_labeled, X_unlabeled, y, beta_dr, resid, proj_dr)StdErrorEstimationDR(X_labeled, X_unlabeled, y, beta_dr, resid, proj_dr)Covariate matrix for labeled data set.
Covariate matrix for unlabeled data set.
Numeric outcome vector.
DR regression parameter estimate to compute the score function.
Estimated residual.
DR projection.